import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';

import { IWatchListEntry, WatchListEntry } from 'app/shared/model/watch-list-entry.model';
import { WatchListEntryService } from './watch-list-entry.service';

@Component({
  selector: 'jhi-watch-list-entry-update',
  templateUrl: './watch-list-entry-update.component.html',
})
export class WatchListEntryUpdateComponent implements OnInit {
  isSaving = false;

  editForm = this.fb.group({
    id: [],
    exerciseId: [null, [Validators.required]],
    exerciseName: [],
  });

  constructor(protected watchListEntryService: WatchListEntryService, protected activatedRoute: ActivatedRoute, private fb: FormBuilder) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ watchListEntry }) => {
      this.updateForm(watchListEntry);
    });
  }

  updateForm(watchListEntry: IWatchListEntry): void {
    this.editForm.patchValue({
      id: watchListEntry.id,
      exerciseId: watchListEntry.exerciseId,
      exerciseName: watchListEntry.exerciseName,
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const watchListEntry = this.createFromForm();
    if (watchListEntry.id !== undefined) {
      this.subscribeToSaveResponse(this.watchListEntryService.update(watchListEntry));
    } else {
      this.subscribeToSaveResponse(this.watchListEntryService.create(watchListEntry));
    }
  }

  private createFromForm(): IWatchListEntry {
    return {
      ...new WatchListEntry(),
      id: this.editForm.get(['id'])!.value,
      exerciseId: this.editForm.get(['exerciseId'])!.value,
      exerciseName: this.editForm.get(['exerciseName'])!.value,
    };
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<IWatchListEntry>>): void {
    result.subscribe(
      () => this.onSaveSuccess(),
      () => this.onSaveError()
    );
  }

  protected onSaveSuccess(): void {
    this.isSaving = false;
    this.previousState();
  }

  protected onSaveError(): void {
    this.isSaving = false;
  }
}
